@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.7 1999/02/23 11:42:40 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,7 +43,7 @@ int
 main (int argc, char *argv [])
 {
 	glibtop_netload netload;
-	unsigned method, count, port, i;
+	unsigned method, count, port;
 	struct in_addr addr, subnet;
 	char *address_string, *subnet_string;
 	char buffer [BUFSIZ];
