@@ -1,23 +1,25 @@
-/* $Id: fsusage.h,v 1.4 1998/10/11 18:13:58 martin Exp $ */
+/* $Id$ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef __GLIBTOP_FSUSAGE_H__
 #define __GLIBTOP_FSUSAGE_H__
@@ -25,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-__BEGIN_DECLS
+BEGIN_LIBGTOP_DECLS
 
 #define GLIBTOP_FSUSAGE_BLOCKS		0
 #define GLIBTOP_FSUSAGE_BFREE		1
@@ -51,9 +53,8 @@ struct _glibtop_fsusage
 
 #define glibtop_get_fsusage_r		glibtop_get_fsusage_s
 
-extern void glibtop_get_fsusage_l __P((glibtop *, glibtop_fsusage *, const char *));
-
-extern void glibtop_get_fsusage_s __P((glibtop *, glibtop_fsusage *, const char *));
+void glibtop_get_fsusage_l (glibtop *server, glibtop_fsusage *buf, const char *mount_dir);
+void glibtop_get_fsusage_s (glibtop *server, glibtop_fsusage *buf, const char *mount_dir);
 
 #ifdef GLIBTOP_NAMES
 
@@ -66,6 +67,6 @@ extern const char *glibtop_descriptions_fsusage [];
 
 #endif
 
-__END_DECLS
+END_LIBGTOP_DECLS
 
 #endif
