@@ -1,23 +1,25 @@
-/* $Id: msg_limits.h,v 1.9 1998/10/11 18:14:02 martin Exp $ */
+/* $Id$ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef __GLIBTOP_MSG_LIMITS_H__
 #define __GLIBTOP_MSG_LIMITS_H__
@@ -25,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-__BEGIN_DECLS
+BEGIN_LIBGTOP_DECLS
 
 #define GLIBTOP_IPC_MSGPOOL	0
 #define GLIBTOP_IPC_MSGMAP	1
@@ -59,14 +61,14 @@ struct _glibtop_msg_limits
 #define glibtop_get_msg_limits_r	glibtop_get_msg_limits_s
 #endif
 
-extern void glibtop_get_msg_limits_l __P((glibtop *, glibtop_msg_limits *));
+void glibtop_get_msg_limits_l (glibtop *server, glibtop_msg_limits *buf);
 
 #if GLIBTOP_SUID_MSG_LIMITS
-extern void glibtop_init_msg_limits_p __P((glibtop *));
-extern void glibtop_get_msg_limits_p __P((glibtop *, glibtop_msg_limits *));
+void glibtop_init_msg_limits_p (glibtop *server);
+void glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf);
 #else
-extern void glibtop_init_msg_limits_s __P((glibtop *));
-extern void glibtop_get_msg_limits_s __P((glibtop *, glibtop_msg_limits *));
+void glibtop_init_msg_limits_s (glibtop *server);
+void glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf);
 #endif
 
 #ifdef GLIBTOP_NAMES
@@ -80,6 +82,7 @@ extern const char *glibtop_descriptions_msg_limits [];
 
 #endif
 
-__END_DECLS
+END_LIBGTOP_DECLS
 
 #endif
+
