@@ -1,4 +1,4 @@
-/* $Id: read.c,v 1.9 1999/02/23 11:43:36 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,6 +30,7 @@ do_read (int s, void *ptr, size_t total_size)
 {
 	int nread;
 	size_t already_read = 0, remaining = total_size;
+	char *tmp_ptr;
 	
 	while (already_read < total_size) {
 		nread = recv (s, ptr, remaining, 0);
@@ -46,7 +47,10 @@ do_read (int s, void *ptr, size_t total_size)
 		
 		already_read += nread;
 		remaining -= nread;
-		(char *) ptr += nread;
+		/* (char *) ptr += nread; */
+		tmp_ptr = ptr;
+		tmp_ptr += nread;
+		ptr = tmp_ptr;
 	}
 }
 
