@@ -1,4 +1,4 @@
-/* $Id: server.c,v 1.11 1999/02/23 11:43:44 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -68,7 +68,7 @@ main(int argc, char *argv[])
 	uid = getuid (); euid = geteuid ();
 	gid = getgid (); egid = getegid ();
 
-	if (uname (&uts)) _exit (1);
+	if (uname (&uts) < 0) _exit (1);
 
 	if (strcmp (uts.sysname, LIBGTOP_COMPILE_SYSTEM) ||
 	    strcmp (uts.release, LIBGTOP_COMPILE_RELEASE) ||
