@@ -1,4 +1,4 @@
-/* $Id: mem.c,v 1.13.4.3 1999/05/27 18:56:47 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -92,7 +92,7 @@ glibtop_init_mem_p (glibtop *server)
 {
 	register int pagesize;
 
-	if (kvm_nlist (server->machine.kd, nlst) != 0) {
+	if (kvm_nlist (server->machine.kd, nlst) < 0) {
 		glibtop_warn_io_r (server, "kvm_nlist (mem)");
 		return;
 	}
