@@ -1,4 +1,4 @@
-/* $Id: ppp.c,v 1.5.4.3 1999/05/27 14:04:00 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -82,7 +82,7 @@ glibtop_init_ppp_p (glibtop *server)
 #endif
 #endif /* HAVE_I4B */
 
-	if (kvm_nlist (server->machine.kd, nlst) != 0)
+	if (kvm_nlist (server->machine.kd, nlst) < 0)
 		glibtop_error_io_r (server, "kvm_nlist");
 }
 
