@@ -1,4 +1,4 @@
-/* $Id: procargs.c,v 1.7 1999/02/23 11:44:07 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -33,7 +33,7 @@
 #include <sys/proc.h>
 
 static const unsigned long _glibtop_sysdeps_proc_args =
-(1 << GLIBTOP_PROC_ARGS_SIZE);
+(1L << GLIBTOP_PROC_ARGS_SIZE);
 
 /* Init function. */
 
@@ -54,18 +54,22 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 	unsigned size = 0, pos = 0;
 	int count;
 
+#ifndef __bsdi__
 	char filename [BUFSIZ];
 	struct stat statb;
+#endif
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_ARGS), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_ARGS), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_args));
 
 	/* swapper, init, pagedaemon, vmdaemon, update - this doen't work. */
 	if (pid < 5) return NULL;
 
+#ifndef __bsdi__
 	sprintf (filename, "/proc/%d/mem", pid);
 	if (stat (filename, &statb)) return NULL;
+#endif
 
 	glibtop_suid_enter (server);
 
