@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.10 1999/02/23 12:58:15 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -42,20 +42,28 @@
 #include <ufs/ufs/inode.h>
 
 #include <sys/ucred.h>
-#ifndef __OpenBSD__
+#if (!defined __OpenBSD__) && (!defined __bsdi__)
 #include <sys/user.h>
 #endif
 #include <sys/sysctl.h>
 #include <vm/vm.h>
 
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+/* Fixme ... */
+#undef _KERNEL
+#define _UVM_UVM_AMAP_I_H_ 1
+#define _UVM_UVM_MAP_I_H_ 1
+#include <uvm/uvm.h>
+#endif
+
 static const unsigned long _glibtop_sysdeps_proc_map =
-(1 << GLIBTOP_PROC_MAP_TOTAL) + (1 << GLIBTOP_PROC_MAP_NUMBER) +
-(1 << GLIBTOP_PROC_MAP_SIZE);
+(1L << GLIBTOP_PROC_MAP_TOTAL) + (1L << GLIBTOP_PROC_MAP_NUMBER) +
+(1L << GLIBTOP_PROC_MAP_SIZE);
 
 static const unsigned long _glibtop_sysdeps_map_entry =
-(1 << GLIBTOP_MAP_ENTRY_START) + (1 << GLIBTOP_MAP_ENTRY_END) +
-(1 << GLIBTOP_MAP_ENTRY_OFFSET) + (1 << GLIBTOP_MAP_ENTRY_PERM) +
-(1 << GLIBTOP_MAP_ENTRY_INODE) + (1 << GLIBTOP_MAP_ENTRY_DEVICE);
+(1L << GLIBTOP_MAP_ENTRY_START) + (1L << GLIBTOP_MAP_ENTRY_END) +
+(1L << GLIBTOP_MAP_ENTRY_OFFSET) + (1L << GLIBTOP_MAP_ENTRY_PERM) +
+(1L << GLIBTOP_MAP_ENTRY_INODE) + (1L << GLIBTOP_MAP_ENTRY_DEVICE);
 
 /* Init function. */
 
@@ -74,15 +82,22 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 	struct kinfo_proc *pinfo;
 	struct vm_map_entry entry, *first;
 	struct vmspace vmspace;
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+	struct vnode vnode;
+	struct inode inode;
+#else
 	struct vm_object object;
+#endif
 	glibtop_map_entry *maps;
+#if defined __FreeBSD__
 	struct vnode vnode;
 	struct inode inode;
 	struct mount mount;
+#endif
 	int count, i = 0;
 	int update = 0;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_MAP), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MAP), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_map));
 
@@ -147,9 +162,14 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
  		if (entry.eflags & (MAP_ENTRY_IS_A_MAP|MAP_ENTRY_IS_SUB_MAP))
  			continue;
 #endif
+#else
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+ 		if (UVM_ET_ISSUBMAP (&entry))
+			continue;
 #else
 		if (entry.is_a_map || entry.is_sub_map)
 			continue;
+#endif
 #endif
 
 		maps [i].flags  = _glibtop_sysdeps_map_entry;
@@ -169,6 +189,19 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
 		i++;
 
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+		if (!entry.object.uvm_obj)
+			continue;
+
+		/* We're only interested in vnodes */
+
+		if (kvm_read (server->machine.kd,
+			      (unsigned long) entry.object.uvm_obj,
+			      &vnode, sizeof (vnode)) != sizeof (vnode)) {
+			glibtop_warn_io_r (server, "kvm_read (vnode)");
+			return NULL;
+		}
+#else
 		if (!entry.object.vm_object)
 			continue;
 
@@ -178,6 +211,24 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 			      (unsigned long) entry.object.vm_object,
 			      &object, sizeof (object)) != sizeof (object))
 			glibtop_error_io_r (server, "kvm_read (object)");
+#endif
+
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+		if (!vnode.v_uvm.u_flags & UVM_VNODE_VALID)
+			continue;
+
+		if ((vnode.v_type != VREG) || (vnode.v_tag != VT_UFS) ||
+		    !vnode.v_data) continue;
+
+		if (kvm_read (server->machine.kd,
+			      (unsigned long) vnode.v_data,
+			      &inode, sizeof (inode)) != sizeof (inode))
+			glibtop_error_io_r (server, "kvm_read (inode)");
+
+		maps [i-1].inode  = inode.i_number;
+		maps [i-1].device = inode.i_dev;
+#endif
+
 
 #ifdef __FreeBSD__
 		/* If the object is of type vnode, add its size */
