@@ -1,4 +1,4 @@
-/* $Id: procsignal.c,v 1.12.2.2 1999/10/16 18:31:43 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -26,7 +26,10 @@
 #include <glibtop/procsignal.h>
 
 #include <glibtop_suid.h>
+
+#ifdef __FreeBSD__
 #include <osreldate.h>
+#endif
 
 static const unsigned long _glibtop_sysdeps_proc_signal =
 (1L << GLIBTOP_PROC_SIGNAL_SIGNAL) +
@@ -88,7 +91,7 @@ glibtop_get_proc_signal_p (glibtop *server,
 #if (defined(__NetBSD__) && (NSIG > 32)) || (__FreeBSD_version >= 400011)
 	buf->sigignore [0] = pinfo [0].kp_proc.p_sigignore.__bits[0];
 #else
-	buf->sigignore [0] = pinfo [0].kp_proc.p_sigignore.__bits[0];
+	buf->sigignore [0] = pinfo [0].kp_proc.p_sigignore;
 #endif
 	
 	/* sigcatch: mask of caught signals.
