@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.13.2.2 1999/09/16 21:05:33 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -290,7 +290,10 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
     }
 
     /* Should never happen. */
-    if (fields < 2) return;
+    if (fields < 2) {
+	fclose (f);
+	return;
+    }
     fields--;
 
     while (fgets (buffer, BUFSIZ-1, f)) {
