@@ -1,4 +1,4 @@
-/* $Id: open.c,v 1.13 1999/02/23 11:45:00 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -62,6 +62,7 @@ glibtop_open_s (glibtop *server, const char *program_name,
 		const unsigned flags)
 {
 	char buffer [BUFSIZ], *p;
+	struct stat statb;
 	int fd, len, i;
 
 	server->name = program_name;
@@ -71,6 +72,13 @@ glibtop_open_s (glibtop *server, const char *program_name,
 
 	server->ncpu = 0;
 
+	/* On Linux 2.4.x, /proc/stat has "cpu" and "cpu0" entries even
+	 * for non-SMP systems. Checking whether /proc/<pid>/cpu exists
+	 * is a much better way to detect SMP. */
+
+	if (stat ("/proc/1/cpu", &statb))
+	    return;
+
 	fd = open (FILENAME, O_RDONLY);
 	if (fd < 0)
 		glibtop_error_io_r (server, "open (%s)", FILENAME);
