@@ -1,4 +1,4 @@
-/* $Id: procargs.c,v 1.3.2.1 1999/05/27 19:24:18 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -60,17 +60,25 @@ glibtop_get_proc_args_s (glibtop *server, glibtop_proc_args *buf,
 		retval = glibtop_malloc_r (server, max_len+1);
 
 		len = read (cmdline, retval, max_len);
+		close (cmdline);
+
 		if (len < 0) {
 			glibtop_free_r (server, retval);
 			return NULL;
 		}
-		
+
+		*(retval+len) = 0;
+
+		buf->size = len;
+		buf->flags = _glibtop_sysdeps_proc_args;
+
 		return retval;
 	}
 
 	while (1) {
 		len = read (cmdline, buffer, BUFSIZ-1);
 		if (len < 0) {
+			close (cmdline);
 			glibtop_free_r (server, retval);
 			return NULL;
 		}
