@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.4 1999/02/23 11:45:06 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,14 +27,14 @@
 #include <glibtop/procmap.h>
 
 static const unsigned long _glibtop_sysdeps_proc_map =
-(1 << GLIBTOP_PROC_MAP_NUMBER) + (1 << GLIBTOP_PROC_MAP_TOTAL) +
-(1 << GLIBTOP_PROC_MAP_SIZE);
+(1L << GLIBTOP_PROC_MAP_NUMBER) + (1L << GLIBTOP_PROC_MAP_TOTAL) +
+(1L << GLIBTOP_PROC_MAP_SIZE);
 
 static const unsigned long _glibtop_sysdeps_map_entry =
-(1 << GLIBTOP_MAP_ENTRY_START) + (1 << GLIBTOP_MAP_ENTRY_END) +
-(1 << GLIBTOP_MAP_ENTRY_OFFSET) + (1 << GLIBTOP_MAP_ENTRY_PERM) +
-(1 << GLIBTOP_MAP_ENTRY_INODE) + (1 << GLIBTOP_MAP_ENTRY_DEVICE) +
-(1 << GLIBTOP_MAP_ENTRY_FILENAME);
+(1L << GLIBTOP_MAP_ENTRY_START) + (1L << GLIBTOP_MAP_ENTRY_END) +
+(1L << GLIBTOP_MAP_ENTRY_OFFSET) + (1L << GLIBTOP_MAP_ENTRY_PERM) +
+(1L << GLIBTOP_MAP_ENTRY_INODE) + (1L << GLIBTOP_MAP_ENTRY_DEVICE) +
+(1L << GLIBTOP_MAP_ENTRY_FILENAME);
 
 /* Init function. */
 
@@ -66,11 +66,15 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 	do {
 		short dev_major, dev_minor;
 		unsigned long start, end, offset, inode, perm;
-		char flags [5];
+		char flags [5], *format;
 		size_t size;
 
-		rv = fscanf (maps,
-			     "%08lx-%08lx %4c\n %08lx %02hx:%02hx %ld",
+		if (sizeof (void*) == 8)
+			format = "%16lx-%16lx %4c\n %16lx %02hx:%02hx %ld";
+		else
+			format = "%08lx-%08lx %4c\n %08lx %02hx:%02hx %ld";
+
+		rv = fscanf (maps, format,
 			     &start, &end, flags, &offset,
 			     &dev_major, &dev_minor, &inode);
 
