@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.14.4.1 1999/05/27 19:24:25 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -59,7 +59,7 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid)
 	 *                   values; NEVER set their flags values if this
 	 *                   is not the case !!! */
 
-	sprintf (buffer, "/proc/%d/stat", pid);
+	sprintf (buffer, "/proc/%d", pid);
 
 	if (stat (buffer, &statb))
 		return;
@@ -72,6 +72,8 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid)
 
 	buf->flags = _glibtop_sysdeps_proc_state_uid;
 
+	sprintf (buffer, "/proc/%d", pid);
+
 	/* Now we read the remaining fields. */
 
 	if (proc_stat_to_buffer (buffer, pid))
