@@ -1,4 +1,4 @@
-/* $Id: shm_limits.c,v 1.8 1999/02/23 11:45:14 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,9 +27,9 @@
 #include <sys/shm.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1 << GLIBTOP_IPC_SHMMAX) + (1 << GLIBTOP_IPC_SHMMIN) +
-(1 << GLIBTOP_IPC_SHMMNI) + (1 << GLIBTOP_IPC_SHMSEG) +
-(1 << GLIBTOP_IPC_SHMALL);
+(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
+(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG) +
+(1L << GLIBTOP_IPC_SHMALL);
 
 /* Init function. */
 
