@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.11.2.1 1999/05/27 19:24:32 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -62,8 +62,8 @@ glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 
 	buffer [len] = '\0';
 
-	buf->uptime   = (float) strtod (buffer, &p);
-	buf->idletime = (float) strtod (p, &p);
+	buf->uptime   = strtod (buffer, &p);
+	buf->idletime = strtod (p, &p);
 
 	buf->flags = _glibtop_sysdeps_uptime;
 }
