@@ -1,4 +1,4 @@
-/* $Id: shm_limits.c,v 1.7 1999/02/23 11:46:09 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,8 +26,8 @@
 #include <glibtop/shm_limits.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1 << GLIBTOP_IPC_SHMMAX) + (1 << GLIBTOP_IPC_SHMMIN) +
-(1 << GLIBTOP_IPC_SHMMNI) + (1 << GLIBTOP_IPC_SHMSEG);
+(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
+(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG);
 
 /* Init function. */
 
@@ -53,7 +53,7 @@ glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 
 	if (ret != 1) return;
 
-	buf->flags += (1 << GLIBTOP_IPC_SHMMAX);
+	buf->flags += (1L << GLIBTOP_IPC_SHMMAX);
 		
 	buf->shmmax = value;
 	
@@ -63,7 +63,7 @@ glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 
 	if (ret != 1) return;
 		
-	buf->flags += (1 << GLIBTOP_IPC_SHMMIN);
+	buf->flags += (1L << GLIBTOP_IPC_SHMMIN);
 		
 	buf->shmmin = value;
 	
@@ -73,7 +73,7 @@ glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 
 	if (ret != 1) return;
 		
-	buf->flags += (1 << GLIBTOP_IPC_SHMMNI);
+	buf->flags += (1L << GLIBTOP_IPC_SHMMNI);
 		
 	buf->shmmni = value;
 	
@@ -83,7 +83,7 @@ glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 
 	if (ret != 1) return;
 		
-	buf->flags += (1 << GLIBTOP_IPC_SHMSEG);
+	buf->flags += (1L << GLIBTOP_IPC_SHMSEG);
 		
 	buf->shmseg = value;
 }
